@@ -8,15 +8,15 @@ use YAML;
 
 =head1 NAME
 
-WWW::Scramble - The great new WWW::Scramble!
+WWW::Scramble - Get only needed from the Web page
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 has mech => ( is => 'ro', isa => 'WWW::Mechanize', default => sub { WWW::Mechanize->new } );
 has handler => (
